==> igniteui-react-charts-16.6.8.tgz: package/ES2015/CommodityChannelIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CommodityChannelIndexIndicatorStrategy } from "./CommodityChannelIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class CommodityChannelIndexIndicator extends StrategyBasedIndicator {
    get_p5() {
        return new CommodityChannelIndexIndicatorStrategy();
    }
    get p5() {
        return this.get_p5();
    }
    get_qi() {
        return CommodityChannelIndexIndicator.$;
    }
    get qi() {
        return this.get_qi();
    }
    get qq() {
        return typeGetValue(this.c(CommodityChannelIndexIndicator.qr));
    }
    set qq(a) {
        this.h(CommodityChannelIndexIndicator.qr, a);
    }
    qb() {
        return this.qq;
    }
    qk(a) {
        this.qq = a;
    }
}
CommodityChannelIndexIndicator.$t = markType(CommodityChannelIndexIndicator, 'CommodityChannelIndexIndicator', StrategyBasedIndicator.$);
CommodityChannelIndexIndicator.qr = StrategyBasedIndicator.qn(20, CommodityChannelIndexIndicator.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/CommodityChannelIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CommodityChannelIndexIndicatorStrategy } from "./CommodityChannelIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class CommodityChannelIndexIndicator extends StrategyBasedIndicator {
    get_qc() {
        return new CommodityChannelIndexIndicatorStrategy();
    }
    get qc() {
        return this.get_qc();
    }
    get_qp() {
        return CommodityChannelIndexIndicator.$;
    }
    get qp() {
        return this.get_qp();
    }
    get qx() {
        return typeGetValue(this.c(CommodityChannelIndexIndicator.qy));
    }
    set qx(a) {
        this.h(CommodityChannelIndexIndicator.qy, a);
    }
    qi() {
        return this.qx;
    }
    qr(a) {
        this.qx = a;
    }
}
CommodityChannelIndexIndicator.$t = markType(CommodityChannelIndexIndicator, 'CommodityChannelIndexIndicator', StrategyBasedIndicator.$);
CommodityChannelIndexIndicator.qy = StrategyBasedIndicator.qu(20, CommodityChannelIndexIndicator.$);
